import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:skripsi_getit/data/model/movie.dart' show Results;
import 'package:skripsi_getit/services/repository/movie_repository.dart';

class TestCubit extends Cubit<List<Results>> {
  final MovieRepository movieRepository;

  TestCubit(this.movieRepository) : super([]);

  Future<void> fetchDataForLoop({int count = 50}) async {
    final stopWatch = Stopwatch()..start();

    List<Results> allMovies = [];
    int totalPages = (count / 20).ceil();

    for (int page = 1; page <= totalPages; page++) {
      final movies = await movieRepository.fetchMoviesforTesting(page: page);
      allMovies.addAll(movies);
    }

    stopWatch.stop();
    print('For Loop completed in ${stopWatch.elapsed.inSeconds} seconds');
    emit(allMovies);
  }

  Future<void> fetchDataWhileLoop({int count = 50}) async {
    final stopWatch = Stopwatch()..start();

    List<Results> allMovies = [];
    int totalPages = (count / 20).ceil();
    int page = 1;

    while (page <= totalPages) {
      final movies = await movieRepository.fetchMoviesforTesting(page: page);
      allMovies.addAll(movies);
      page++;
    }

    stopWatch.stop();
    print('While Loop completed in ${stopWatch.elapsed.inSeconds} seconds');
    emit(allMovies);
  }

  Future<void> fetchDataDoWhileLoop({int count = 50}) async {
    final stopWatch = Stopwatch()..start();

    List<Results> allMovies = [];
    int totalPages = (count / 20).ceil();
    int page = 1;

    do {
      final movies = await movieRepository.fetchMoviesforTesting(page: page);
      allMovies.addAll(movies);
      page++;
    } while (page <= totalPages);

    stopWatch.stop();
    print('Do While Loop completed in ${stopWatch.elapsed.inSeconds} seconds');
    emit(allMovies);
  }

  Results? binarySearchByTitle(String title) {
    final sortedList = [...state];
    sortedList.sort((a, b) => (a.title ?? '').compareTo(b.title ?? ''));

    int left = 0;
    int right = sortedList.length - 1;

    while (left <= right) {
      int mid = (left + right) ~/ 2;
      String midTitle = sortedList[mid].title ?? '';

      if (midTitle == title) {
        return sortedList[mid];
      } else if (midTitle.compareTo(title) < 0) {
        left = mid + 1;
      } else {
        right = mid - 1;
      }
    }

    return null;
  }

  void compareAllMoviesByRating() {
    final stopwatch = Stopwatch()..start();

    for (int i = 0; i < state.length; i++) {
      for (int j = 0; j < state.length; j++) {
        if (i != j) {
          final movieA = state[i];
          final movieB = state[j];
          bool sameRating = movieA.voteAverage == movieB.voteAverage;

          if (sameRating) {
            print(
              '${movieA.title} dan ${movieB.title} memiliki rating yang sama',
            );
          }
        }
      }
    }

    stopwatch.stop();
    print("O(n²) selesai dalam: ${stopwatch.elapsedMilliseconds} ms");
  }

  void reset() {
    emit([]);
  }
}
